<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 10/12/2008 *
 * ===================                          Last change: 10/12/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : ext-debug.php                                    *
 * -------------------------------------------------------------------- *
 * Short description : Extension for sending/receiving debug requests   *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Erweiterung zum Versenden/Empfangen von Debug-Q. *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Version number
setThisExtensionVersion('0.0.0');

// Version history array (add more with , '0.0.1' and so on)
setExtensionVersionHistory(array('0.0.0'));

// Keep this extension always active!
setExtensionAlwaysActive('Y');

// This extension is in development (non-productive)
enableExtensionProductive(false);

switch (getExtensionMode()) {
	case 'register': // Do stuff when installation is running
		// Table for debug log entries
		addDropTableSql('debug_log');
		addCreateTableSql('debug_log', "(
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`sender_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`timestamp` TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00',
`file` VARCHAR(255) NOT NULL DEFAULT '',
`line` MEDIUMINT NOT NOT NULL DEFAULT 0,
`message` LONGTEXT,
`comment` TINYTEXT,
`status` ENUM('NEW','PENDING','ACCEPTED','FIXED','INVALID','DUBLICATE','SPAM') NOT NULL DEFAULT 'NEW',
`inserted` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
INDEX (`sender_id`),
PRIMARY KEY (`id`)
) TYPE = {?_TABLE_TYPE?} CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT = 'Debug log data'");

		// Table against debug log abuse
		addDropTableSql('debug_log_abuse');
		addCreateTableSql('debug_log_abuse', "(
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`client_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`timestamp` TIMESTAMP NOT NULL DEFAULT '0000-00-00 00:00',
`raw_data` LONGTEXT,
`inserted` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
INDEX (`client_id`),
PRIMARY KEY (`id`)
) TYPE = {?_TABLE_TYPE?} CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT = 'Debug log abuse'");

		// Table on relay/server for client exchanges
		addDropTableSql('debug_client');
		addCreateTableSql('debug_client', "(
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`key` VARCHAR(255) NOT NULL DEFAULT 'SELF',
`url` VARCHAR(255) NOT NULL DEFAULT '',
`webmaster` VARCHAR(255) NOT NULL DEFAULT '',
`title` VARCHAR(255) NOT NULL DEFAULT '',
`status` ENUM('ACTIVE','NEW','PENDING','LOCKED','DELETED','SPAM') NOT NULL DEFAULT 'PENDING',
`type` ENUM ('CLIENT','RELAY','SERVER') NOT NULL DEFAULT 'CLIENT',
`inserted` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
`lock_spam_reason` TINYTEXT,
UNIQUE (`key`),
UNIQUE (`url`),
PRIMARY KEY (`id`)
) TYPE = {?_TABLE_TYPE?} CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT = 'Debug clients'");

		// Add this exchange as first client
		addExtensionSql("INSERT INTO `{?_MYSQL_PREFIX?}_debug_client` (`url`,`title`,`webmaster`,`status`) VALUES ('{?URL?}','{?MAIN_TITLE?}','{?WEBMASTER?}','ACTIVE')");

		// Table for debug log <-> client connection
		addDropTableSql('debug_client_log');
		addCreateTableSql('debug_client_log', "(
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`client_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 1,
`log_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
INDEX `client_log` (`client_id`,`log_id`),
UNIQUE (`log_id`),
PRIMARY KEY (`id`)
) TYPE = {?_TABLE_TYPE?} CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT = 'Debug client <-> log connection'");

		// Guest menus
		addGuestMenuSql('debug',NULL,'Debug-System','Y','Y',2);
		addGuestMenuSql('debug','debug_info','Informationen','Y','Y',1);
		addGuestMenuSql('debug','debug_reg','Anmeldung','Y','Y',2);
		addGuestMenuSql('debug','debug_unreg','Abmeldung','Y','Y',3);
		addGuestMenuSql('debug','debug_pilory','Spam-Pranger','Y','Y',4);

		// Admin menu
		addAdminMenuSql('debug', NULL, 'Debug-System', 'Verwalten Sie hier komfortabel das debug.log, welches sich im Verzeichnis <strong>{?CACHE_PATH?}</strong> befindet.', 10);
		addAdminMenuSql('debug', 'import_debug', 'debug.log importieren', 'Importieren Sie hier manuell die debug.log, damit neue Eintr&auml;ge mit bestehenden abgeglichen werden k&ouml;nnen und dann evtl. hinzugef&uuml;gt werden. Die <em>debug.log</em> wird nach dem Import automatisch vom Server entfernt. Dieser Vorgang wird f&uuml;r Sie nachts automatisch erledigt!', 1);
		addAdminMenuSql('debug', 'list_debug', 'Eintr&auml;ge anzeigen', 'Listet alle bereits importierten Eintr&auml;ge auf. Von hier aus versenden Sie noch nicht gemeldete Fehler an das Relay-Netzwerk, damt diese vom Entwicklerteam gepr&uuml;ft werden k&ouml;nnen.', 2);
		addAdminMenuSql('debug', 'reg_debug', 'Am Server anmelden', 'Sie m&uuml;ssen zuerst Ihren Debug-Client (Ihr {?mt_word?} ist dies) oder Relay am Server von mxchange.org anmelden. Dies geschieht f&uuml;r Sie nicht automatisch, da Sie Ihre Daten zuvor &uuml;berpr&uuml;fen m&uuml;ssen, wie z.B. URL, eMail-Adresse und {?mt_word?}-Titel.', 3);
		addAdminMenuSql('debug', 'unreg_debug', 'Vom Server abmelden', 'Melden Sie bitte Ihren {?mt_word?} wieder vom Projekt-Server ab, damit mein Entwicklerteam weiss, welche Keys nicht mehr genutzt werden.', 4);
		addAdminMenuSql('debug', 'config_debug', 'Einstellungen', '&Auml;ndern Sie hier alle Einstellungen, wie auch den Debug-Modus - ob Client, Hub oder selber Server sein. Lesen Sie dazu die Anleitung unter DOCs/de/debug/README.txt durch! Oder kommen Sie in&#39;s Forum. Das Team von mxchange.org hilft Ihnen gerne weiter.', 5);

		// Config entries
		addConfigAddSql('debug_id', 'BIGINT(20) UNSIGNED NOT NULL DEFAULT 0');
		addConfigAddSql('debug_key', "VARCHAR(255) NOT NULL DEFAULT ''");
		addConfigAddSql('debug_mode', "ENUM('CLIENT','RELAY','SERVER') NOT NULL DEFAULT 'CLIENT'");
		addConfigAddSql('debug_new_log', "ENUM('ACCEPT','FIRST','REG') NOT NULL DEFAULT 'FIRST'");
		addConfigAddSql('debug_new_client', "ENUM('ACTIVE','NEW','REG') NOT NULL DEFAULT 'NEW'");
		addConfigAddSql('debug_reject_log', 'BIGINT(20) UNSIGNED NOT NULL DEFAULT ' . (getOneDay() * 30));
		addConfigAddSql('debug_master_url', "VARCHAR(255) NOT NULL DEFAULT '{?SERVER_URL?}'");
		break;

	case 'remove': // Do stuff when removing extension
		// SQL commands to run
		addDropTableSql('debug_client_log');
		addDropTableSql('debug_client');
		addDropTableSql('debug_log');
		addDropTableSql('debug_log_abuse');
		addExtensionSql("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_guest_menu` WHERE `action`='debug'");
		addExtensionSql("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_admin_menu` WHERE `action`='debug'");
		break;

	case 'activate': // Do stuff when admin activates this extension
		// SQL commands to run
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_guest_menu` SET `visible`='Y',`locked`='N' WHERE `action`='debug' LIMIT 5");
		break;

	case 'deactivate': // Do stuff when admin deactivates this extension
		// SQL commands to run
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_guest_menu` SET `locked`='Y' WHERE `action`='debug' LIMIT 5");
		break;

	case 'update': // Update an extension
		switch (getCurrentExtensionVersion()) {
			case '0.0.1': // SQL queries for v0.0.1
				addExtensionSql('');

				// Update notes (these will be set as task text!)
				setExtensionUpdateNotes('');
				break;
		} // END - switch
		break;

	case 'modify': // When the extension got modified
		break;

	case 'test': // For testing purposes
		break;

	case 'init': // Do stuff when extension is initialized
		break;

	default: // Unknown extension mode
		logDebugMessage(__FILE__, __LINE__, sprintf("Unknown extension mode %s in extension %s detected.", getExtensionMode(), getCurrentExtensionName()));
		break;
} // END - switch

// [EOF]
?>
